==> cargo-binstall-1.15.7-1.src.tar.gz: cargo-binstall-1.15.7/crates/detect-wasi/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.0.38](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.37...detect-wasi-v1.0.38) - 2025-09-06

### Other

- update Cargo.lock dependencies

## [1.0.37](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.36...detect-wasi-v1.0.37) - 2025-08-30

### Other

- update Cargo.lock dependencies

## [1.0.36](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.35...detect-wasi-v1.0.36) - 2025-08-24

### Other

- update Cargo.lock dependencies

## [1.0.35](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.34...detect-wasi-v1.0.35) - 2025-08-22

### Other

- update Cargo.lock dependencies

## [1.0.34](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.33...detect-wasi-v1.0.34) - 2025-08-01

### Other

- update Cargo.lock dependencies

## [1.0.33](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.32...detect-wasi-v1.0.33) - 2025-07-25

### Other

- update Cargo.lock dependencies
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.0.42](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.41...detect-wasi-v1.0.42) - 2025-10-10

### Other

- update Cargo.lock dependencies

## [1.0.41](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.40...detect-wasi-v1.0.41) - 2025-09-26

### Other

- update Cargo.lock dependencies

## [1.0.40](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.39...detect-wasi-v1.0.40) - 2025-09-19

### Other

- update Cargo.lock dependencies

## [1.0.39](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.38...detect-wasi-v1.0.39) - 2025-09-14

### Other

- update Cargo.lock dependencies

## [1.0.32](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.31...detect-wasi-v1.0.32) - 2025-06-21

### Other

- update Cargo.lock dependencies

## [1.0.31](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.30...detect-wasi-v1.0.31) - 2025-06-10

### Other

- update Cargo.lock dependencies

## [1.0.30](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.29...detect-wasi-v1.0.30) - 2025-05-16

### Other

- update Cargo.lock dependencies

## [1.0.29](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.28...detect-wasi-v1.0.29) - 2025-05-07

### Other

- update Cargo.lock dependencies

## [1.0.28](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.27...detect-wasi-v1.0.28) - 2025-04-05

### Other

- update Cargo.lock dependencies

## [1.0.27](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.26...detect-wasi-v1.0.27) - 2025-03-19

### Other

- update Cargo.lock dependencies

## [1.0.26](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.25...detect-wasi-v1.0.26) - 2025-03-15

### Other

- update Cargo.lock dependencies

## [1.0.25](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.24...detect-wasi-v1.0.25) - 2025-03-07

### Other

- update Cargo.lock dependencies

## [1.0.24](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.23...detect-wasi-v1.0.24) - 2025-02-28

### Other

- update Cargo.lock dependencies

## [1.0.23](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.22...detect-wasi-v1.0.23) - 2025-02-22

### Other

- update Cargo.lock dependencies

## [1.0.22](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.21...detect-wasi-v1.0.22) - 2025-02-11

### Other

- update Cargo.lock dependencies

## [1.0.21](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.20...detect-wasi-v1.0.21) - 2025-02-04

### Other

- update Cargo.lock dependencies

## [1.0.20](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.19...detect-wasi-v1.0.20) - 2025-01-19

### Other

- update Cargo.lock dependencies

## [1.0.19](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.18...detect-wasi-v1.0.19) - 2025-01-11

### Other

- update Cargo.lock dependencies

## [1.0.18](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.17...detect-wasi-v1.0.18) - 2025-01-04

### Other

- update Cargo.lock dependencies

## [1.0.17](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.16...detect-wasi-v1.0.17) - 2024-12-28

### Other

- update Cargo.lock dependencies

## [1.0.16](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.15...detect-wasi-v1.0.16) - 2024-12-14

### Other

- update Cargo.lock dependencies

## [1.0.15](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.14...detect-wasi-v1.0.15) - 2024-12-07

### Other

- update Cargo.lock dependencies

## [1.0.14](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.13...detect-wasi-v1.0.14) - 2024-11-29

### Other

- update Cargo.lock dependencies

## [1.0.13](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.12...detect-wasi-v1.0.13) - 2024-11-23

### Other

- update Cargo.lock dependencies

## [1.0.12](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.11...detect-wasi-v1.0.12) - 2024-11-18

### Other

- update Cargo.lock dependencies

## [1.0.11](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.10...detect-wasi-v1.0.11) - 2024-11-09

### Other

- update Cargo.lock dependencies

## [1.0.10](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.9...detect-wasi-v1.0.10) - 2024-11-05

### Other

- update Cargo.lock dependencies

## [1.0.9](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.8...detect-wasi-v1.0.9) - 2024-11-02

### Other

- update Cargo.lock dependencies

## [1.0.8](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.7...detect-wasi-v1.0.8) - 2024-10-25

### Other

- update Cargo.lock dependencies

## [1.0.7](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.6...detect-wasi-v1.0.7) - 2024-10-12

### Other

- update Cargo.lock dependencies

## [1.0.6](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.5...detect-wasi-v1.0.6) - 2024-10-04

### Other

- update Cargo.lock dependencies

## [1.0.5](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.4...detect-wasi-v1.0.5) - 2024-09-22

### Other

- update Cargo.lock dependencies

## [1.0.4](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.3...detect-wasi-v1.0.4) - 2024-09-06

### Other
- update Cargo.lock dependencies

## [1.0.3](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.2...detect-wasi-v1.0.3) - 2024-08-25

### Other
- update Cargo.lock dependencies

## [1.0.2](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.1...detect-wasi-v1.0.2) - 2024-08-10

### Other
- update Cargo.lock dependencies

## [1.0.1](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.0...detect-wasi-v1.0.1) - 2024-08-04

### Other
- Bump tempfile from 3.4.0 to 3.5.0 ([#967](https://github.com/cargo-bins/cargo-binstall/pull/967))
- Bump tempfile from 3.3.0 to 3.4.0 ([#834](https://github.com/cargo-bins/cargo-binstall/pull/834))
- Migrate CI and builds to Just, add "full" builds ([#660](https://github.com/cargo-bins/cargo-binstall/pull/660))

==> cargo-binstall-1.15.9-1.src.tar.gz: cargo-binstall-1.15.9/crates/detect-wasi/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.0.38](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.37...detect-wasi-v1.0.38) - 2025-09-06

### Other

- update Cargo.lock dependencies

## [1.0.37](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.36...detect-wasi-v1.0.37) - 2025-08-30

### Other

- update Cargo.lock dependencies

## [1.0.36](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.35...detect-wasi-v1.0.36) - 2025-08-24

### Other

- update Cargo.lock dependencies

## [1.0.35](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.34...detect-wasi-v1.0.35) - 2025-08-22

### Other

- update Cargo.lock dependencies

## [1.0.34](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.33...detect-wasi-v1.0.34) - 2025-08-01

### Other

- update Cargo.lock dependencies

## [1.0.33](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.32...detect-wasi-v1.0.33) - 2025-07-25

### Other

- update Cargo.lock dependencies
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.0.43](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.42...detect-wasi-v1.0.43) - 2025-10-24

### Other

- update Cargo.lock dependencies

## [1.0.42](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.41...detect-wasi-v1.0.42) - 2025-10-10

### Other

- update Cargo.lock dependencies

## [1.0.41](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.40...detect-wasi-v1.0.41) - 2025-09-26

### Other

- update Cargo.lock dependencies

## [1.0.40](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.39...detect-wasi-v1.0.40) - 2025-09-19

### Other

- update Cargo.lock dependencies

## [1.0.39](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.38...detect-wasi-v1.0.39) - 2025-09-14

### Other

- update Cargo.lock dependencies

## [1.0.32](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.31...detect-wasi-v1.0.32) - 2025-06-21

### Other

- update Cargo.lock dependencies

## [1.0.31](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.30...detect-wasi-v1.0.31) - 2025-06-10

### Other

- update Cargo.lock dependencies

## [1.0.30](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.29...detect-wasi-v1.0.30) - 2025-05-16

### Other

- update Cargo.lock dependencies

## [1.0.29](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.28...detect-wasi-v1.0.29) - 2025-05-07

### Other

- update Cargo.lock dependencies

## [1.0.28](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.27...detect-wasi-v1.0.28) - 2025-04-05

### Other

- update Cargo.lock dependencies

## [1.0.27](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.26...detect-wasi-v1.0.27) - 2025-03-19

### Other

- update Cargo.lock dependencies

## [1.0.26](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.25...detect-wasi-v1.0.26) - 2025-03-15

### Other

- update Cargo.lock dependencies

## [1.0.25](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.24...detect-wasi-v1.0.25) - 2025-03-07

### Other

- update Cargo.lock dependencies

## [1.0.24](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.23...detect-wasi-v1.0.24) - 2025-02-28

### Other

- update Cargo.lock dependencies

## [1.0.23](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.22...detect-wasi-v1.0.23) - 2025-02-22

### Other

- update Cargo.lock dependencies

## [1.0.22](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.21...detect-wasi-v1.0.22) - 2025-02-11

### Other

- update Cargo.lock dependencies

## [1.0.21](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.20...detect-wasi-v1.0.21) - 2025-02-04

### Other

- update Cargo.lock dependencies

## [1.0.20](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.19...detect-wasi-v1.0.20) - 2025-01-19

### Other

- update Cargo.lock dependencies

## [1.0.19](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.18...detect-wasi-v1.0.19) - 2025-01-11

### Other

- update Cargo.lock dependencies

## [1.0.18](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.17...detect-wasi-v1.0.18) - 2025-01-04

### Other

- update Cargo.lock dependencies

## [1.0.17](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.16...detect-wasi-v1.0.17) - 2024-12-28

### Other

- update Cargo.lock dependencies

## [1.0.16](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.15...detect-wasi-v1.0.16) - 2024-12-14

### Other

- update Cargo.lock dependencies

## [1.0.15](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.14...detect-wasi-v1.0.15) - 2024-12-07

### Other

- update Cargo.lock dependencies

## [1.0.14](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.13...detect-wasi-v1.0.14) - 2024-11-29

### Other

- update Cargo.lock dependencies

## [1.0.13](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.12...detect-wasi-v1.0.13) - 2024-11-23

### Other

- update Cargo.lock dependencies

## [1.0.12](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.11...detect-wasi-v1.0.12) - 2024-11-18

### Other

- update Cargo.lock dependencies

## [1.0.11](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.10...detect-wasi-v1.0.11) - 2024-11-09

### Other

- update Cargo.lock dependencies

## [1.0.10](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.9...detect-wasi-v1.0.10) - 2024-11-05

### Other

- update Cargo.lock dependencies

## [1.0.9](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.8...detect-wasi-v1.0.9) - 2024-11-02

### Other

- update Cargo.lock dependencies

## [1.0.8](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.7...detect-wasi-v1.0.8) - 2024-10-25

### Other

- update Cargo.lock dependencies

## [1.0.7](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.6...detect-wasi-v1.0.7) - 2024-10-12

### Other

- update Cargo.lock dependencies

## [1.0.6](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.5...detect-wasi-v1.0.6) - 2024-10-04

### Other

- update Cargo.lock dependencies

## [1.0.5](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.4...detect-wasi-v1.0.5) - 2024-09-22

### Other

- update Cargo.lock dependencies

## [1.0.4](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.3...detect-wasi-v1.0.4) - 2024-09-06

### Other
- update Cargo.lock dependencies

## [1.0.3](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.2...detect-wasi-v1.0.3) - 2024-08-25

### Other
- update Cargo.lock dependencies

## [1.0.2](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.1...detect-wasi-v1.0.2) - 2024-08-10

### Other
- update Cargo.lock dependencies

## [1.0.1](https://github.com/cargo-bins/cargo-binstall/compare/detect-wasi-v1.0.0...detect-wasi-v1.0.1) - 2024-08-04

### Other
- Bump tempfile from 3.4.0 to 3.5.0 ([#967](https://github.com/cargo-bins/cargo-binstall/pull/967))
- Bump tempfile from 3.3.0 to 3.4.0 ([#834](https://github.com/cargo-bins/cargo-binstall/pull/834))
- Migrate CI and builds to Just, add "full" builds ([#660](https://github.com/cargo-bins/cargo-binstall/pull/660))
